==> Products.EEADesign2006-1.1.zip: Products.EEADesign2006-1.1/Products/EEADesign2006/browser/mail.py <==
from threading import Thread
from zope.interface import implements
from Products.EEADesign2006.interfaces import IMailTranslationService
from valentine.gtranslate import translate_plus, InvalidLanguagePairError, ServiceUnavailableError
from Acquisition import aq_inner
from Zope import DB
import transaction


class ThreadedMail(Thread):

    """Takes a message, translates and sends it in a separate thread.

    Useful when this operation would otherwise slow down the user
    experience.
    """

    def __init__(self, plone_id, fromlang, tolang, original, template, *args, **kwargs):
        super(ThreadedMail, self).__init__()
        self.plone_id = plone_id
        self.fromlang = fromlang
        self.tolang = tolang
        self.original = original
        self.template = template
        self.args = args
        self.kwargs = kwargs

    def translate(self):
        if self.fromlang == 'en':
            return 'Original language is english, so no translation required'
        try:
            langpair = self.fromlang + '|' + self.tolang
            translation = translate_plus(self.original, langpair)
        except InvalidLanguagePairError:
            translation = 'No translation available for language %s' % self.fromlang
        except ServiceUnavailableError:
            translation = 'Translation service unavailable'
        return translation
        
    def run(self):
        conn = DB.open()
        root = conn.root()
        app = root['Application']
        host = app[self.plone_id].MailHost
        translation = self.translate().encode('utf-8')
        msg = self.template.replace('[AUTOMATED_TRANSLATION]', translation)
        self.result = host.secureSend(msg, *self.args, **self.kwargs)
        transaction.commit()


class MailTranslationService(object):

    implements(IMailTranslationService)

    def __init__(self, context, request):
        self.context = [context]
        self.request = request

    def __call__(self, plone_id, variables, *args, **kwargs):
        fromlang = self.request.get('LANGUAGE', 'en')
        tolang = 'en'
        context = self.context[0]
        template = context.site_feedback_template(context, **variables)
        original = variables['message']

        # Store a reference so that the test can join it
        self.mail = ThreadedMail(plone_id, fromlang, tolang, original, template, *args, **kwargs)
        self.mail.start()

==> Products.EEADesign2006-1.5.zip: Products.EEADesign2006-1.5/Products/EEADesign2006/browser/mail.py <==
""" Mail
"""
from threading import Thread
from zope.interface import implements
from Products.EEADesign2006.interfaces import IMailTranslationService
from Zope2 import DB
import transaction
from valentine.gtranslate import (
    translate_plus,
    InvalidLanguagePairError,
    ServiceUnavailableError,
)

class ThreadedMail(Thread):

    """Takes a message, translates and sends it in a separate thread.

    Useful when this operation would otherwise slow down the user
    experience.
    """

    def __init__(self, plone_id, fromlang, tolang, original,
                 template, *args, **kwargs):
        super(ThreadedMail, self).__init__()
        self.plone_id = plone_id
        self.fromlang = fromlang
        self.tolang = tolang
        self.original = original
        self.template = template
        self.args = args
        self.kwargs = kwargs

    def translate(self):
        """ Translate
        """
        if self.fromlang == 'en':
            return 'Original language is english, so no translation required'
        try:
            langpair = self.fromlang + '|' + self.tolang
            translation = translate_plus(self.original, langpair)
        except InvalidLanguagePairError:
            translation = ("No translation available for "
                           "language %s" % self.fromlang)
        except ServiceUnavailableError:
            translation = 'Translation service unavailable'
        return translation

    def run(self):
        """ Run
        """
        conn = DB.open()
        root = conn.root()
        app = root['Application']
        host = app[self.plone_id].MailHost
        translation = self.translate().encode('utf-8')
        msg = self.template.replace('[AUTOMATED_TRANSLATION]', translation)
        self.result = host.secureSend(msg, *self.args, **self.kwargs)
        transaction.commit()


class MailTranslationService(object):
    """ Mail translation service
    """
    implements(IMailTranslationService)

    def __init__(self, context, request):
        self.context = [context]
        self.request = request

    def __call__(self, plone_id, variables, *args, **kwargs):
        fromlang = self.request.get('LANGUAGE', 'en')
        tolang = 'en'
        context = self.context[0]
        template = context.site_feedback_template(context, **variables)
        original = variables['message']

        # Store a reference so that the test can join it
        self.mail = ThreadedMail(plone_id, fromlang, tolang,
                                 original, template, *args, **kwargs)
        self.mail.start()
